@@ -2,7 +2,10 @@
 """
 Initialization of the optimize subpackage
 """
-
+from .linprog_simplex import (
+    linprog_simplex, solve_tableau, get_solution, PivOptions
+)
+from .minmax import minmax
 from .scalar_maximization import brent_max
 from .nelder_mead import nelder_mead
 from .root_finding import newton, newton_halley, newton_secant, bisect, brentq
